#wdecoster
'''
Example usage:
zcat reads.fastq.gz | NanoFilt.py -q 10 -l 500 --headcrop 50 | bwa mem -t 48 -x ont2d genome.fa - | samtools sort -O BAM -@24 -o alignment.bam -
'''

from __future__ import print_function
from Bio import SeqIO
import argparse
import sys
from nanomath import aveQual
from nanofilt.version import __version__


def main():
    args = getArgs()
    filterstream(sys.stdin, args)


def getArgs():
    parser = argparse.ArgumentParser(description="Perform quality and or length filtering of Nanopore fastq data on stdin.")
    parser.add_argument("-v", "--version", help="Print version and exit.", action="version", version='NanoFilt {}'.format(__version__))
    parser.add_argument("-q", "--quality", help="Filter on a minimum average read quality score", default=0, type=int)
    parser.add_argument("-l", "--length", help="Filter on a minimum read length", default=0, type=int)
    parser.add_argument("--headcrop", help="Trim n nucleotides from start of read", default=None, type=int)
    parser.add_argument("--tailcrop", help="Trim n nucleotides from end of read", default=None, type=int)
    return parser.parse_args()


def filterstream(fq, args):
    '''
    If a fastq record passes quality filter (optional) and length filter (optional), print to stdout
    Optionally trim a number of nucleotides from beginning and end.
    '''
    for record in SeqIO.parse(fq, "fastq"):
        if aveQual(record.letter_annotations["phred_quality"]) > args.quality and len(record) > args.length:
            print(record[args.headcrop:args.tailcrop].format("fastq"), end="")

if __name__ == "__main__":
    main()



# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

exec(open('nanofilt/version.py').read())

setup(
    name='NanoFilt',
    version=__version__,
    description='Filtering and trimming of Oxford Nanopore Sequencing data',
    long_description='Filtering and trimming of Oxford Nanopore Sequencing data.',
    url='https://github.com/wdecoster/nanofilt',
    author='Wouter De Coster',
    author_email='decosterwouter@gmail.com',
    license='MIT',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Science/Research',
        'Topic :: Scientific/Engineering :: Bio-Informatics',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    keywords='nanopore sequencing processing trimming filtering',
    packages=find_packages(),
    install_requires=['biopython', 'nanomath'],
    package_data={'nanofilt': []},
        package_dir={'nanofilt': 'nanofilt'},
        include_package_data=True,
        entry_points={
            'console_scripts': ['NanoFilt=nanofilt.NanoFilt:main',]}
)
